Changelog
---------

- **1.0** (2013-11-21)

  - Minor improvements to setup script, comments, and docs.
  - Support for "python -m expak".
  - Removal of race in subdirectory creation in nop_converter.

- **0.9** (2013-11-19)

  - Initial upload to PyPI. No known issues, but starting with a beta classifier
    until I'm sure that the packaging is correct.
